NestedLiveViewState

Enum NestedLiveViewState 

pub enum NestedLiveViewState {
    Mounted,
    Suspended,
    Terminated,
}
Runtime lifecycle state for one nested LiveView.

Variants



Mounted

Child is mounted and accepts scoped events.



Suspended

Child keeps server state but does not accept browser events.



Terminated

Child has terminated and no longer accepts events or renders.