ServerMessage

Enum ServerMessage 

pub enum ServerMessage {
Show 27 variants Hello { session_id: String, target: String, revision: u64, protocol: String, server_revision: Option<u64>, resume_status: Option<ResumeStatus>, resume_reason: Option<String>, resume_token: Option<String>, resume_expires_in_ms: Option<u64>, }, Patch { target: String, html: String, revision: u64, }, Diff { target: String, revision: u64, slots: Vec<DynamicSlotPatch>, }, StreamInsert { target: String, id: String, html: String, at: StreamPosition, }, StreamDelete { target: String, id: String, }, StreamBatch { target: String, operations: Vec<StreamBatchOperation>, }, ChartSeriesAppend { chart: String, series: String, point: ChartPoint, }, ChartSeriesAppendMany { chart: String, series: String, points: Vec<ChartPoint>, }, ChartSeriesReplace { chart: String, series: String, points: Vec<ChartPoint>, }, ChartReset { chart: String, }, ChartAnnotationUpsert { chart: String, annotation: ChartAnnotation, }, ChartAnnotationDelete { chart: String, id: String, }, ToastPush { toast: Toast, }, ToastDismiss { id: String, }, InboxUpsert { item: InboxItem, }, InboxDelete { id: String, }, GridReplace { grid: String, state: GridState, }, GridRowsReplace { grid: String, window: GridRowsWindow, }, InteropDispatch { dispatch: JsInteropDispatch, }, Pong { nonce: Option<String>, }, Redirect { to: String, }, PatchUrl { to: String, }, Navigate { to: String, }, UploadProgress { upload_id: String, received: u64, total: u64, }, UploadComplete { upload_id: String, name: String, size: u64, content_type: Option<String>, }, UploadError { upload_id: String, message: String, code: Option<String>, }, Error { message: String, code: Option<String>, },
}
Message sent from the Rust runtime to the browser runtime.

Variants



Hello

Sent when the WebSocket is established.

Fields

session_id: String
target: String
revision: u64
protocol: String
server_revision: Option<u64>
resume_status: Option<ResumeStatus>
resume_reason: Option<String>
resume_token: Option<String>
resume_expires_in_ms: Option<u64>


Patch

Replace or morph a target node’s inner content.

Fields

target: String
html: String
revision: u64


Diff

Replace changed dynamic slots within a previously patched template.

Fields

target: String
revision: u64


StreamInsert

Insert one rendered item into a browser stream.

Fields

target: String
html: String


StreamDelete

Delete one rendered item from a browser stream.

Fields

target: String


StreamBatch

Apply many stream operations in one message.

Fields

target: String


ChartSeriesAppend

Append one point into a browser-managed chart series.

Fields

chart: String
series: String


ChartSeriesAppendMany

Append many points into one browser-managed chart series.

Fields

chart: String
series: String
points: Vec<ChartPoint>


ChartSeriesReplace

Replace one chart series with a full point set.

Fields

chart: String
series: String
points: Vec<ChartPoint>


ChartReset

Clear all chart series data for one chart.

Fields

chart: String


ChartAnnotationUpsert

Insert or replace one chart annotation.

Fields

chart: String
annotation: ChartAnnotation


ChartAnnotationDelete

Delete one chart annotation.

Fields

chart: String


ToastPush

Push one toast notification.

Fields

toast: Toast


ToastDismiss

Dismiss one toast notification by id.

Fields



InboxUpsert

Insert or replace one inbox item.

Fields



InboxDelete

Delete one inbox item.

Fields



GridReplace

Replace one enterprise grid state snapshot.

Fields

grid: String


GridRowsReplace

Replace only the active row window of one enterprise grid.

Fields

grid: String


InteropDispatch

Dispatch one browser-side interop event.

Fields



Pong

Reply to a ping.

Fields



Redirect

Navigate the browser to another URL.

Fields



PatchUrl

Patch the browser URL using history.pushState without replacing the view.

Fields



Navigate

Navigate to another internal LiveView route using history.pushState.

Fields



UploadProgress

Report upload transfer progress.

Fields

upload_id: String
received: u64
total: u64


UploadComplete

Report a completed upload.

Fields

upload_id: String
name: String
size: u64
content_type: Option<String>


UploadError

Report an upload-specific validation or transport error.

Fields

upload_id: String
message: String


Error

Report a recoverable server-side error.

Fields

message: String