Context

Struct Context 

pub struct Context { /* private fields */ }
Mutable context passed into LiveView lifecycle callbacks.

Implementations

Source

impl Context

pub fn new(target_dom_id: impl Into<String>) -> Self

Create context for a new LiveView session.

pub fn session_id(&self) -> &SessionId

The current session id.

pub fn target_dom_id(&self) -> &str

The DOM id targeted by patches.

pub fn route_path(&self) -> &str

Current request path for this LiveView session.

pub fn route_params(&self) -> &BTreeMap<String, String>

Current route params matched by the transport adapter.

pub fn route_param(&self, key: &str) -> Option<&str>

Borrow one current route param.

pub fn tenant_id(&self) -> Option<&str>

Tenant context associated with this session.

pub fn set_tenant_id(&mut self, tenant_id: impl Into<String>)

Set tenant context associated with this session.

pub fn set_tenant_id_optional(&mut self, tenant_id: Option<String>)

Replace tenant context associated with this session.

pub fn clear_tenant_id(&mut self)

Clear tenant context associated with this session.

pub fn is_connected(&self) -> bool

Whether this context is currently attached to a WebSocket.

pub fn set_connected(&mut self, connected: bool)

Mark this context as connected or disconnected.

pub fn push_message(&mut self, message: ServerMessage)

Queue an imperative server message.

pub fn subscribe(&mut self, topic: impl Into<String>)

Subscribe this session to an in-process PubSub topic.

pub fn broadcast( &mut self, topic: impl Into<String>, messages: Vec<ServerMessage>, )

Broadcast server messages to all subscribers on a topic.

pub fn broadcast_message( &mut self, topic: impl Into<String>, message: ServerMessage, )

Broadcast one server message to all subscribers on a topic.

pub fn schedule_once( &mut self, id: impl Into<String>, delay_ms: u64, event: impl Into<String>, value: impl Into<Value>, )

Schedule one synthetic event to be dispatched after delay_ms.

pub fn schedule_once_to( &mut self, id: impl Into<String>, delay_ms: u64, target: impl Into<String>, event: impl Into<String>, value: impl Into<Value>, )

Schedule one synthetic scoped event to be dispatched after delay_ms.

pub fn schedule_interval( &mut self, id: impl Into<String>, every_ms: u64, event: impl Into<String>, value: impl Into<Value>, )

Schedule a recurring synthetic event every every_ms.

pub fn schedule_interval_to( &mut self, id: impl Into<String>, every_ms: u64, target: impl Into<String>, event: impl Into<String>, value: impl Into<Value>, )

Schedule a recurring scoped synthetic event every every_ms.

pub fn cancel_schedule(&mut self, id: impl Into<String>)

Cancel a previously scheduled runtime command by id.

pub fn request_render(&mut self)

Request a root render after the current event.

pub fn set_render_cadence_ms(&mut self, cadence_ms: u64)

Override root render cadence for this session in milliseconds.

0 keeps immediate render behavior.

pub fn clear_render_cadence_override(&mut self)

Clear any session-level render cadence override.

pub fn skip_render(&mut self)

Suppress the automatic root render after the current event.

pub fn redirect(&mut self, to: impl Into<String>)

Queue a browser redirect.

pub fn patch_url(&mut self, to: impl Into<String>)

Queue a URL patch without replacing the current LiveView.

pub fn navigate(&mut self, to: impl Into<String>)

Queue an internal LiveView navigation.

pub fn stream_insert( &mut self, target: impl Into<String>, id: impl Into<String>, html: impl Into<String>, at: StreamPosition, )

Queue insertion of one item into a browser stream.

pub fn stream_append( &mut self, target: impl Into<String>, id: impl Into<String>, html: impl Into<String>, )

Queue append of one item into a browser stream.

pub fn stream_prepend( &mut self, target: impl Into<String>, id: impl Into<String>, html: impl Into<String>, )

Queue prepend of one item into a browser stream.

pub fn stream_delete( &mut self, target: impl Into<String>, id: impl Into<String>, )

Queue deletion of one item from a browser stream.

pub fn stream_batch( &mut self, target: impl Into<String>, operations: Vec<StreamBatchOperation>, )

Queue many stream operations as one protocol message.

pub fn stream_append_many( &mut self, target: impl Into<String>, items: Vec<(String, String)>, )

Queue append of many items into a browser stream.

pub fn stream_prepend_many( &mut self, target: impl Into<String>, items: Vec<(String, String)>, )

Queue prepend of many items into a browser stream.

pub fn chart_series_append( &mut self, chart: impl Into<String>, series: impl Into<String>, point: ChartPoint, )

Queue append of one point into a browser-managed chart series.

pub fn chart_series_append_many( &mut self, chart: impl Into<String>, series: impl Into<String>, points: Vec<ChartPoint>, )

Queue append of many points into one browser-managed chart series.

pub fn chart_series_replace( &mut self, chart: impl Into<String>, series: impl Into<String>, points: Vec<ChartPoint>, )

Queue replacement of one chart series with a full point set.

pub fn chart_reset(&mut self, chart: impl Into<String>)

Queue clearing of all series data for one chart.

pub fn chart_annotation_upsert( &mut self, chart: impl Into<String>, annotation: ChartAnnotation, )

Queue insert or replacement of one chart annotation.

pub fn chart_annotation_delete( &mut self, chart: impl Into<String>, id: impl Into<String>, )

Queue deletion of one chart annotation.

pub fn toast_push(&mut self, toast: Toast)

Queue one toast notification for browser display.

pub fn toast_dismiss(&mut self, id: impl Into<String>)

Queue dismissal of one toast notification.

pub fn inbox_upsert(&mut self, item: InboxItem)

Queue insert or replacement of one inbox item.

pub fn inbox_delete(&mut self, id: impl Into<String>)

Queue deletion of one inbox item.

pub fn grid_replace(&mut self, grid: impl Into<String>, state: GridState)

Queue a full enterprise-grid snapshot update.

pub fn grid_rows_replace( &mut self, grid: impl Into<String>, offset: usize, total_rows: usize, rows: Vec<GridRow>, )

Queue replacement of one active enterprise-grid row window.

pub fn interop_dispatch( &mut self, event: impl Into<String>, detail: impl Into<Value>, )

Dispatch one browser interop event to document.

pub fn interop_dispatch_to( &mut self, target: impl Into<Option<String>>, event: impl Into<String>, detail: impl Into<Value>, )

Dispatch one browser interop event to a specific target id.

pub fn webrtc_signal(&mut self, detail: impl Into<Value>)

Dispatch one WebRTC signaling payload.

pub fn webrtc_signal_to( &mut self, target: impl Into<String>, detail: impl Into<Value>, )

Dispatch one WebRTC signaling payload to a specific target id.