pub struct DynamicSlotPatch {
pub index: usize,
pub html: String,
}Expand description
Dynamic slot update sent by a diff server message.
Fields
index: usizehtml: StringTrait Implementations
Sourceimpl Clone for DynamicSlotPatch
impl Clone for DynamicSlotPatch
Sourcefn clone(&self) -> DynamicSlotPatch
fn clone(&self) -> DynamicSlotPatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DynamicSlotPatch
impl Debug for DynamicSlotPatch
Sourceimpl<'de> Deserialize<'de> for DynamicSlotPatch
impl<'de> Deserialize<'de> for DynamicSlotPatch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DynamicSlotPatch
impl PartialEq for DynamicSlotPatch
Sourcefn eq(&self, other: &DynamicSlotPatch) -> bool
fn eq(&self, other: &DynamicSlotPatch) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DynamicSlotPatch
impl Serialize for DynamicSlotPatch
impl Eq for DynamicSlotPatch
impl StructuralPartialEq for DynamicSlotPatch