PubSub

Struct PubSub 

pub struct PubSub { /* private fields */ }
Adapter-owned PubSub runtime abstraction.

Implementations

Source

impl PubSub

pub fn new(topic_capacity: usize) -> Self

Create the built-in in-process backend.

pub fn with_backend<B>(backend: B) -> Self
where B: PubSubBackend + 'static,

Wrap a custom backend implementation (for clustered fanout backends).

pub fn subscribe(&self, topic: impl Into<String>) -> PubSubSubscription

Subscribe to a topic.

pub fn broadcast( &self, topic: impl Into<String>, messages: Vec<ServerMessage>, ) -> usize

Broadcast one payload to all subscribers on a topic.

pub fn capabilities(&self) -> PubSubCapabilities

Backend cluster/delivery capability contract.

pub fn register_presence( &self, topic: impl Into<String>, session_id: impl Into<String>, node_id: impl Into<String>, )

Register one session as present for a topic on one cluster node.

pub fn unregister_presence( &self, topic: impl Into<String>, session_id: impl Into<String>, node_id: impl Into<String>, )

Unregister one session presence from a topic on one cluster node.

pub fn presence_snapshot( &self, topic: impl Into<String>, ) -> PubSubPresenceSnapshot

Return presence counts for one topic.